==> pycate-0.1.5.tar.gz: pycate-0.1.5/pycate/handlers/add_handler.py <==
# -*- coding:utf-8 -*-
'''
添加信息
'''
import time
import tornado.web
from torlite.core import tools
from pycate.core import base_handler
from config import cfg as c
from pycate.model.catalog_model import MCatalog

import config


class AddHandler(base_handler.PycateBaseHandler):
    def initialize(self, hinfo=''):
        self.init_condition(config.mongo_collection_name)
        self.mcat = MCatalog()

    def get(self, input=''):
        url_arr = input.split('/')
        if len(input) == 4:
            self.toadd(input)
        elif len(url_arr[0]) == 4 and url_arr[1] == 'vip':
            self.toadd(url_arr[0], '1')
        else:
            self.render('404.html')

    def post(self, input=''):
        if len(input) > 0:
            self.add()

    @tornado.web.authenticated
    def toadd(self, catid, vip='0'):
        if self.userinfo.privilege[2] == '1':
            pass
        else:
            return

        ip = self.request.remote_ip
        uid = tools.get_uuid()
        kwd = {
            'uid': uid,
            'userid': self.userinfo.user_name,
            'catid': catid,
            'parentid': catid[:2] + '00',
            'parentname': self.mcat.get_by_id(catid[:2] + '00').catname,
            'catname': self.mcat.get_by_id(catid).catname,
            'parentlist': self.mcat.get_parent_list(),
            'chenghu': '',
            'phone': '',
            'qq': '',
            'email': self.userinfo.user_email,
            'userip': ip,
            'vip': vip,
        }
        self.render('{0}/autogen/add/add_{1}.html'.format(self.template_dir_name, catid), kwd=kwd)

    @tornado.web.authenticated
    def add(self):

        if self.userinfo.privilege[2] == '1':
            pass
        else:
            return

        post_data = {'mymps_img': [], }
        for key in self.request.arguments:
            post_data[key] = self.get_arguments(key)

        uid = post_data['uid'][0]
        # 对uid进行判断，防止反复发布同一信息。
        uu = self.minfo.get_by_id(uid)
        if str(uu) == 'None':
            pass
        else:
            self.render('not_repeat.html')
            return

        ts = tools.timestamp()

        # parentid = post_data['parentid'][0]
        post_data['catname'] = self.mcat.get_by_id(post_data['catid'][0]).catname
        post_data['userid'] = self.userinfo.user_name
        post_data['views'] = 1
        post_data['create_time'] = ts
        post_data['update_time'] = ts

        ## 添加控制字段
        post_data['def_uid'] = str(uid)
        post_data['def_create_time_str'] = time.localtime(ts)
        post_data['def_update_time_str'] = time.localtime(ts)

        # 记录的超时的时间
        # 推广
        post_data['def_tuiguang_out_time'] = ts
        # 置顶
        post_data['def_zhiding'] = 0
        post_data['def_zhiding_out_time'] = ts
        # 刷新
        post_data['def_refresh'] = 1
        post_data['def_refresh_out_time'] = ts + c.refresh_timeout
        # 是否有效。是否通过审核
        post_data['def_valid'] = 1
        post_data['def_banned'] = 0


        post_data['def_tuiguang'] = 0

        if self.minfo.insert_data(post_data) == True:
            self.redirect('/list/{0}'.format(post_data['catid'][0]))
        else:
            self.render('error.html')

==> pycate-0.1.6.tar.gz: pycate-0.1.6/pycate/handlers/add_handler.py <==
# -*- coding:utf-8 -*-
'''
添加信息
'''
import time
import tornado.web
from torlite.core import tools
from pycate.core import base_handler
from config import cfg as c
from pycate.model.catalog_model import MCatalog

import config


class AddHandler(base_handler.PycateBaseHandler):
    def initialize(self, hinfo=''):
        self.init_condition(config.mongo_collection_name)
        self.mcat = MCatalog()

    def get(self, url_str=''):
        if len(url_str) == 4:
            self.to_add(url_str)
        else:
            self.render('html/404.html', kwd = {'info': '非法输入，请选择正确的类别!'})

    def post(self, url_str=''):
        if len(url_str) == 4:
            self.add()
        else:
            self.render('html/404.html', kwd = {'info': '非法输入，请选择正确的类别!'})


    @tornado.web.authenticated
    def to_add(self, catid, vip='0'):
        if self.userinfo.privilege[2] == '1':
            pass
        else:
            return

        ip = self.request.remote_ip
        uid = tools.get_uuid()
        kwd = {
            'uid': uid,
            'userid': self.userinfo.user_name,
            'catid': catid,
            'parentid': catid[:2] + '00',
            'parentname': self.mcat.get_by_id(catid[:2] + '00').catname,
            'catname': self.mcat.get_by_id(catid).catname,
            'userip': ip,
            'vip': vip,
        }
        self.render('{0}/autogen/add/add_{1}.html'.format(self.template_dir_name, catid), kwd=kwd)

    @tornado.web.authenticated
    def add(self):
        if self.userinfo.privilege[2] == '1':
            pass
        else:
            return

        post_data = {'mymps_img': [], }
        for key in self.request.arguments:
            post_data[key] = self.get_arguments(key)

        uid = post_data['uid'][0]
        # 对uid进行判断，防止反复发布同一信息。
        uu = self.minfo.get_by_id(uid)
        if str(uu) == 'None':
            pass
        else:
            self.render('not_repeat.html')
            return

        ts = tools.timestamp()

        post_data['catname'] = self.mcat.get_by_id(post_data['catid'][0]).catname
        post_data['userid'] = self.userinfo.user_name
        post_data['views'] = 1
        post_data['create_time'] = ts
        post_data['update_time'] = ts

        # 添加控制字段
        post_data['def_uid'] = str(uid)
        post_data['def_create_time_str'] = time.localtime(ts)
        post_data['def_update_time_str'] = time.localtime(ts)

        # 记录的超时的时间
        # 推广
        post_data['def_tuiguang_out_time'] = ts
        # 置顶
        post_data['def_zhiding'] = 0
        post_data['def_zhiding_out_time'] = ts
        # 刷新
        post_data['def_refresh'] = 1
        post_data['def_refresh_out_time'] = ts + c.refresh_timeout
        # 是否有效。是否通过审核
        post_data['def_valid'] = 1
        post_data['def_banned'] = 0
        post_data['keywords'] = [x.strip() for x in post_data['keywords'][0].split(',')]
        post_data['def_tuiguang'] = 0

        if self.minfo.insert_data(post_data):
            self.redirect('/list/{0}'.format(post_data['catid'][0]))
        else:
            self.render('{0}/error.html'.format(self.template_dir_name))
